==> nip2_7.24.1.orig.tar.gz: nip2-7.24.1/src/colourview.h <==
/* a colourview in a workspace
 */

/*

    Copyright (C) 1991-2003 The National Gallery

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

/*

    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk

*/

#define TYPE_COLOURVIEW (colourview_get_type())
#define COLOURVIEW( obj ) (GTK_CHECK_CAST( (obj), TYPE_COLOURVIEW, Colourview ))
#define COLOURVIEW_CLASS( klass ) \
	(GTK_CHECK_CLASS_CAST( (klass), TYPE_COLOURVIEW, ColourviewClass ))
#define IS_COLOURVIEW( obj ) (GTK_CHECK_TYPE( (obj), TYPE_COLOURVIEW ))
#define IS_COLOURVIEW_CLASS( klass ) \
	(GTK_CHECK_CLASS_TYPE( (klass), TYPE_COLOURVIEW ))

typedef struct _Colourview {
	Graphicview parent_object;

	Colourdisplay *colourdisplay;
	Conversion *conv;
	GtkWidget *label;
} Colourview;

typedef struct _ColourviewClass {
	GraphicviewClass parent_class;

	/* My methods.
	 */
} ColourviewClass;

GtkType colourview_get_type( void );
View *colourview_new( void );

==> nip-7.8.14.tar.gz: nip-7.8.14/src/colourview.h <==
/* a colourview in a workspace
 */

/*

    Copyright (C) 1991-2003 The National Gallery

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

/*

    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk

*/

#define TYPE_COLOURVIEW (colourview_get_type())
#define COLOURVIEW( obj ) (GTK_CHECK_CAST( (obj), TYPE_COLOURVIEW, Colourview ))
#define COLOURVIEW_CLASS( klass ) \
	(GTK_CHECK_CLASS_CAST( (klass), TYPE_COLOURVIEW, ColourviewClass ))
#define IS_COLOURVIEW( obj ) (GTK_CHECK_TYPE( (obj), TYPE_COLOURVIEW ))
#define IS_COLOURVIEW_CLASS( klass ) \
	(GTK_CHECK_CLASS_TYPE( (klass), TYPE_COLOURVIEW ))

typedef struct _Colourview {
	View view;

        guint popup_sid;	/* id for popup menu */

	Colourdisplay *colourdisplay;
	Conversion *conv;
	GtkWidget *label;
} Colourview;

typedef struct _ColourviewClass {
	ViewClass parent_class;

	/* My methods.
	 */
} ColourviewClass;

GtkType colourview_get_type( void );
View *colourview_new( void );
